.protect-uploads-error {
	border: 2px solid #dc3232;
	display: inline-block;
	padding: 10px;
}
.protect-uploads-success {
	border: 1px solid #46b450;
}

/* container left and right */
.protect-uploads .protect-uploads-main-container {
    float: left;
    width: 66%;
}
.protect-uploads .protect-uploads-sidebar {
    float: left;
    width: 31%;
    margin-left: 2%;
}

.protect-uploads-disabled {
    opacity: 0.75 !important;
}